@@ -4,10 +4,11 @@
   Foundation.libs.accordion = {
     name : 'accordion',
 
-    version : '5.2.0',
+    version : '5.2.2',
 
     settings : {
       active_class: 'active',
+      multi_expand: false,
       toggleable: true
     },
 
@@ -24,7 +25,7 @@
         var accordion = S(this).closest('[' + self.attr_name() + ']'),
             target = S('#' + this.href.split('#')[1]),
             siblings = S('dd > .content', accordion),
-            aunts = $('> dd', accordion),
+            aunts = $('dd', accordion),
             settings = accordion.data(self.attr_name(true) + '-init'),
             active_content = S('dd > .content.' + settings.active_class, accordion),
             active_parent = S('dd.' + settings.active_class, accordion);
@@ -32,13 +33,16 @@
 
         if (! S(this).closest('dl').is(accordion)) { return; }
 
-        if (active_content[0] == target[0] && settings.toggleable) {
+        if (settings.toggleable && target.is(active_content)) {
           active_parent.toggleClass(settings.active_class, false);
           return target.toggleClass(settings.active_class, false);
         }
 
-        siblings.removeClass(settings.active_class);
-        aunts.removeClass(settings.active_class);
+        if (!settings.multi_expand) {
+          siblings.removeClass(settings.active_class);
+          aunts.removeClass(settings.active_class);
+        }
+
         target.addClass(settings.active_class).parent().addClass(settings.active_class);
       });
     },
